@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000, 2001, 2002 Marco Pesenti Gritti
+ *  Copyright © 2000, 2001, 2002 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -13,9 +13,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-embed-dialog.c,v 1.11 2005/01/08 19:41:46 chpe Exp $
+ *  $Id: ephy-embed-dialog.c 6952 2007-03-11 19:42:02Z chpe $
  */
 
 #include "config.h"
@@ -61,7 +61,7 @@ ephy_embed_dialog_get_type (void)
 
         if (G_UNLIKELY (type == 0))
         {
-                static const GTypeInfo our_info =
+                const GTypeInfo our_info =
                 {
                         sizeof (EphyEmbedDialogClass),
                         NULL, /* base_init */
@@ -99,7 +99,7 @@ ephy_embed_dialog_class_init (EphyEmbedDialogClass *klass)
                                                               "Embed",
                                                               "The dialog's embed",
                                                               G_TYPE_OBJECT,
-                                                              G_PARAM_READWRITE));
+                                                              G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
 	g_type_class_add_private (object_class, sizeof(EphyEmbedDialogPrivate));
 }
