@@ -1,3 +1,4 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  *  Copyright © 2002 Jorn Baayen
  *  Copyright © 2003, 2004 Marco Pesenti Gritti
@@ -15,9 +16,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-file-helpers.c,v 1.51 2006/10/15 14:05:39 wbolster Exp $
+ *  $Id: ephy-file-helpers.c 6952 2007-03-11 19:42:02Z chpe $
  */
 
 #include "config.h"
@@ -1007,10 +1008,7 @@ ephy_file_launch_handler (const char *mime_type,
 		gnome_vfs_mime_application_free (app);
 	}
 	else
-	{
-		/* FIXME: warn user? */
-		g_warning ("No handler for found or file type is unsafe!\n");
-	}
+		ret = FALSE;
 
 	g_free (canonical);
 
